@@ -52,10 +52,10 @@ class Environment:
         """read in data about celestial body and unpack"""
 
         #read in json file
-        with open(data) as f:
-            data = json.load(f)
+        with open(self.data) as f:
+            data_json = json.load(f)
 
-        celestial_body_dict = data[self.celestial_body]
+        celestial_body_dict = data_json[self.celestial_body]
 
         # unpack json file
         self.cb_mass = celestial_body_dict['mass_kg']
